# Generated by Django 3.2.19 on 2023-06-01 13:54

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aimmo', '0031_alter_avatar_auth_token'),
    ]

    operations = [
        migrations.AlterField(
            model_name='game',
            name='target_num_pickups_per_avatar',
            field=models.FloatField(default=0),
        ),
    ]
