# Generated by Django 3.2.18 on 2023-04-11 14:55

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aimmo', '0030_update_created_by'),
    ]

    operations = [
        migrations.AlterField(
            model_name='avatar',
            name='auth_token',
            field=models.CharField(blank=True, max_length=24),
        ),
    ]
